@@ -1,19 +1,18 @@
 #!/usr/bin/python3
 # -*- coding: utf-8 -*-
 
-import sys
 import unittest
-
-from mock import (
+from unittest.mock import (
     Mock,
 )
 
+from test.test_base import TestBase
+
 from unattended_upgrade import calculate_upgradable_pkgs
 
 
-class TestBlacklistedWrongOrigin(unittest.TestCase):
+class TestBlacklistedWrongOrigin(TestBase):
 
-    @unittest.skipIf(sys.version_info[0] != 3, "only works on py3")
     def test_if_origin_does_not_match_then_blacklist_is_not_checked(self):
         origin = Mock()
         origin.origin = "some-other-origin"
@@ -29,16 +28,13 @@ class TestBlacklistedWrongOrigin(unittest.TestCase):
         cache = Mock()
         cache.__iter__ = Mock(return_value=iter([pkg]))
         options = Mock()
+        cache.allowed_origins = ["o=allowed-origin"]
+        cache.blacklist = ["postgresql"]
+        cache.whitelist = []
 
-        pkgs_to_upgrade, pkgs_kept_back = \
-            calculate_upgradable_pkgs(cache,
-                                      options,
-                                      ["o=allowed-origin"],
-                                      ["postgresql"],
-                                      [])
+        pkgs_to_upgrade = calculate_upgradable_pkgs(cache, options)
 
         self.assertListEqual([], pkgs_to_upgrade)
-        self.assertListEqual([], pkgs_kept_back)
 
 
 if __name__ == "__main__":
